==> yadifa-2.6.5-1-x86_64.pkg.tar.zst: usr/include/dnslg/dnslg-config-features.h <==
#pragma once
#define DNSLG_DEFAULT_ASSUMED_CPU_COUNT 2
#define DNSLG_HAS_ACL_SUPPORT 1
#define DNSLG_HAS_BFD_DEBUG_SUPPORT 0
#define DNSLG_HAS_BUILD_TIMESTAMP 1
#define DNSLG_HAS_CC_ADDRESS_SANITIZER_CHECK 0
#define DNSLG_HAS_CC_ANSI 1
#define DNSLG_HAS_CC_ANSI_ALIAS 0
#define DNSLG_HAS_CC_CATCH_UNDEFINED_BEHAVIOR 0
#define DNSLG_HAS_CC_DWARF2 1
#define DNSLG_HAS_CC_DWARF3 1
#define DNSLG_HAS_CC_DWARF4 1
#define DNSLG_HAS_CC_EXCEPTIONS 1
#define DNSLG_HAS_CC_G 1
#define DNSLG_HAS_CC_G3 1
#define DNSLG_HAS_CC_M32 0
#define DNSLG_HAS_CC_M64 1
#define DNSLG_HAS_CC_MISSING_FIELD_INITIALIZERS 1
#define DNSLG_HAS_CC_NO_IDENT 1
#define DNSLG_HAS_CC_NO_OMIT_FRAME_POINTER 1
#define DNSLG_HAS_CC_PEDANTIC 1
#define DNSLG_HAS_CC_RDYNAMIC 1
#define DNSLG_HAS_CC_SANITIZE_ADDRESS 1
#define DNSLG_HAS_CC_STACK_PROTECTOR 1
#define DNSLG_HAS_CC_STD_C11 1
#define DNSLG_HAS_CC_STD_C99 1
#define DNSLG_HAS_CC_STD_GNU11 1
#define DNSLG_HAS_CC_STD_GNU99 1
#define DNSLG_HAS_CC_TUNE_NATIVE 1
#define DNSLG_HAS_CC_WALL 1
#define DNSLG_HAS_CC_XC99 0
#define DNSLG_HAS_CLOSE_EX_REF 0
#define DNSLG_HAS_CPU_AMDINTEL 1
#define DNSLG_HAS_CTRL 1
#define DNSLG_HAS_DNSSEC_SUPPORT 1
#define DNSLG_HAS_DNSSEC_TOOLS 1
#define DNSLG_HAS_DYNUPDATE_SUPPORT 1
#define DNSLG_HAS_ECDSA_SUPPORT 1
#define DNSLG_HAS_EDDSA_SUPPORT 1
#define DNSLG_HAS_EVENT_DYNAMIC_MODULE 0
#define DNSLG_HAS_EVP_PKEY_NEW_RAW_PUBLIC_KEY 1
#define DNSLG_HAS_FULL_ASCII7 0
#define DNSLG_HAS_KEYGEN 0
#define DNSLG_HAS_LIBC_MALLOC_DEBUG_SUPPORT 0
#define DNSLG_HAS_LOCK_DEBUG_SUPPORT 0
#define DNSLG_HAS_LOGDIR 1
#define DNSLG_HAS_LOG_PID 1
#define DNSLG_HAS_LOG_THREAD_ID 0
#define DNSLG_HAS_LOG_THREAD_TAG 1
#define DNSLG_HAS_MALLOC_DEBUG_SUPPORT 0
#define DNSLG_HAS_MASTER_SUPPORT 1
#define DNSLG_HAS_MEMALIGN_ISSUES 0
#define DNSLG_HAS_MUTEX_DEBUG_SUPPORT 0
#define DNSLG_HAS_NON_AA_AXFR_SUPPORT 0
#define DNSLG_HAS_NSEC3_SUPPORT 1
#define DNSLG_HAS_NSEC_SUPPORT 1
#define DNSLG_HAS_NSID_SUPPORT 1
#define DNSLG_HAS_OPENSSL 1
#define DNSLG_HAS_PTHREAD_SETAFFINITY_NP 1
#define DNSLG_HAS_PTHREAD_SETNAME_NP 1
#define DNSLG_HAS_PTHREAD_SPINLOCK 1
#define DNSLG_HAS_RRL_SUPPORT 1
#define DNSLG_HAS_RRSIG_MANAGEMENT_SUPPORT 1
#define DNSLG_HAS_SETGROUPS 1
#define DNSLG_HAS_SOCKADDR_IN6_SIN6_LEN 0
#define DNSLG_HAS_SOCKADDR_IN_SIN_LEN 0
#define DNSLG_HAS_SOCKADDR_SA_LEN 0
#define DNSLG_HAS_SYNC_BUILTINS 1
#define DNSLG_HAS_SYSTEMD_RESOLVED_AVOIDANCE 1
#define DNSLG_HAS_TESTS 1
#define DNSLG_HAS_TOOLS 1
#define DNSLG_HAS_TRACK_ZONES_DEBUG_SUPPORT 0
#define DNSLG_HAS_TSIG_SUPPORT 1
#define DNSLG_HAS_WITH_LOGDIR "/var/log/yadifa" // /var/log/yadifa
#define DNSLG_HAS_YADIFA 1
#define DNSLG_HAS_ZALLOC_DEBUG_SUPPORT 0
#define DNSLG_HAS_ZALLOC_STATISTICS_SUPPORT 0
#define DNSLG_HAS_ZALLOC_SUPPORT 1
#define DNSLG_HAVE_ALARM 1
#define DNSLG_HAVE_ARPA_INET_H 1
#define DNSLG_HAVE_ASM_UNISTD_H 1
#define DNSLG_HAVE_ASSERT_H 1
#define DNSLG_HAVE_ATEXIT 1
#define DNSLG_HAVE_BFD_H 1
#define DNSLG_HAVE_BYTESWAP_H 1
#define DNSLG_HAVE_BZERO 1
#define DNSLG_HAVE_CHOWN 1
#define DNSLG_HAVE_CLOCK_GETTIME 1
#define DNSLG_HAVE_CPUID_H 1
#define DNSLG_HAVE_CTYPE_H 1
#define DNSLG_HAVE_DIRENT_H 1
#define DNSLG_HAVE_DLFCN_H 1
#define DNSLG_HAVE_DUP2 1
#define DNSLG_HAVE_ENDIAN_H 1
#define DNSLG_HAVE_ERRNO_H 1
#define DNSLG_HAVE_EXECINFO_H 1
#define DNSLG_HAVE_FCNTL_H 1
#define DNSLG_HAVE_FDATASYNC 1
#define DNSLG_HAVE_FORK 1
#define DNSLG_HAVE_FTRUNCATE 1
#define DNSLG_HAVE_GETCWD 1
#define DNSLG_HAVE_GETHOSTNAME 1
#define DNSLG_HAVE_GETOPT_H 1
#define DNSLG_HAVE_GETPAGESIZE 1
#define DNSLG_HAVE_GETTID 1
#define DNSLG_HAVE_GETTIMEOFDAY 1
#define DNSLG_HAVE_GRP_H 1
#define DNSLG_HAVE_INET_NTOA 1
#define DNSLG_HAVE_INT16_T 1
#define DNSLG_HAVE_INT32_T 1
#define DNSLG_HAVE_INT64_T 1
#define DNSLG_HAVE_INT8_T 1
#define DNSLG_HAVE_INTTYPES_H 1
#define DNSLG_HAVE_LIBC 1
#define DNSLG_HAVE_LIMITS_H 1
#define DNSLG_HAVE_LINUX_LIMITS_H 1
#define DNSLG_HAVE_LOCALTIME_R 1
#define DNSLG_HAVE_LONG_LONG 1
#define DNSLG_HAVE_MALLOC 1
#define DNSLG_HAVE_MALLOC_H 1
#define DNSLG_HAVE_MEMCHR 1
#define DNSLG_HAVE_MEMMOVE 1
#define DNSLG_HAVE_MEMORY_H 1
#define DNSLG_HAVE_MEMSET 1
#define DNSLG_HAVE_MKDIR 1
#define DNSLG_HAVE_MKFIFO 1
#define DNSLG_HAVE_MMAP 1
#define DNSLG_HAVE_MUNMAP 1
#define DNSLG_HAVE_NETDB_H 1
#define DNSLG_HAVE_NETINET_IN_H 1
#define DNSLG_HAVE_NETINET_TCP_H 1
#define DNSLG_HAVE_NET_ETHERNET_H 1
#define DNSLG_HAVE_POLL_H 1
#define DNSLG_HAVE_PTHREAD_H 1
#define DNSLG_HAVE_PTRDIFF_T 1
#define DNSLG_HAVE_PWD_H 1
#define DNSLG_HAVE_REALLOC 1
#define DNSLG_HAVE_RECVMMSG 1
#define DNSLG_HAVE_SCHED_H 1
#define DNSLG_HAVE_SELECT 1
#define DNSLG_HAVE_SENDMMSG 1
#define DNSLG_HAVE_SIGNAL_H 1
#define DNSLG_HAVE_SOCKET 1
#define DNSLG_HAVE_STDARG_H 1
#define DNSLG_HAVE_STDATOMIC_H 1
#define DNSLG_HAVE_STDBOOL_H 1
#define DNSLG_HAVE_STDDEF_H 1
#define DNSLG_HAVE_STDINT_H 1
#define DNSLG_HAVE_STDIO_H 1
#define DNSLG_HAVE_STDLIB_H 1
#define DNSLG_HAVE_STDNORETURN_H 1
#define DNSLG_HAVE_STRCASECMP 1
#define DNSLG_HAVE_STRCHR 1
#define DNSLG_HAVE_STRDUP 1
#define DNSLG_HAVE_STRERROR 1
#define DNSLG_HAVE_STRINGS_H 1
#define DNSLG_HAVE_STRING_H 1
#define DNSLG_HAVE_STRNCASECMP 1
#define DNSLG_HAVE_STRRCHR 1
#define DNSLG_HAVE_STRTOL 1
#define DNSLG_HAVE_STRUCT_TM_TM_ZONE 1
#define DNSLG_HAVE_SYSLOG_H 1
#define DNSLG_HAVE_SYS_FILE_H 1
#define DNSLG_HAVE_SYS_IOCTL_H 1
#define DNSLG_HAVE_SYS_IPC_H 1
#define DNSLG_HAVE_SYS_MMAN_H 1
#define DNSLG_HAVE_SYS_MSG_H 1
#define DNSLG_HAVE_SYS_PARAM_H 1
#define DNSLG_HAVE_SYS_PRCTL_H 1
#define DNSLG_HAVE_SYS_RESOURCE_H 1
#define DNSLG_HAVE_SYS_SELECT_H 1
#define DNSLG_HAVE_SYS_SOCKET_H 1
#define DNSLG_HAVE_SYS_STAT_H 1
#define DNSLG_HAVE_SYS_TIME_H 1
#define DNSLG_HAVE_SYS_TYPES_H 1
#define DNSLG_HAVE_SYS_UN_H 1
#define DNSLG_HAVE_SYS_WAIT_H 1
#define DNSLG_HAVE_TIMEGM 1
#define DNSLG_HAVE_TIME_H 1
#define DNSLG_HAVE_TM_ZONE 1
#define DNSLG_HAVE_UCONTEXT_H 1
#define DNSLG_HAVE_UINT16_T 1
#define DNSLG_HAVE_UINT32_T 1
#define DNSLG_HAVE_UINT64_T 1
#define DNSLG_HAVE_UINT8_T 1
#define DNSLG_HAVE_UNISTD_H 1
#define DNSLG_HAVE_U_CHAR 1
#define DNSLG_HAVE_VFORK 1
#define DNSLG_HAVE_WORKING_FORK 1
#define DNSLG_HAVE_WORKING_VFORK 1
#define DNSLG_HAVE__BOOL 1
#define DNSLG_IS_BSD_FAMILY 0
#define DNSLG_IS_DARWIN_OS 0
#define DNSLG_IS_LINUX_FAMILY 1
#define DNSLG_IS_SOLARIS_FAMILY 0
#define DNSLG_LSTAT_FOLLOWS_SLASHED_SYMLINK 1
#define DNSLG_LT_OBJDIR ".libs/"
#define DNSLG_PACKAGE "yadifa"
#define DNSLG_PACKAGE_BUGREPORT "info@yadifa.eu"
#define DNSLG_PACKAGE_NAME "yadifa"
#define DNSLG_PACKAGE_STRING "yadifa 2.6.5-11201"
#define DNSLG_PACKAGE_TARNAME "yadifa"
#define DNSLG_PACKAGE_URL ""
#define DNSLG_PACKAGE_VERSION "2.6.5-11201"
#define DNSLG_SELECT_TYPE_ARG1 int
#define DNSLG_SELECT_TYPE_ARG234 (fd_set *)
#define DNSLG_SELECT_TYPE_ARG5 (struct timeval *)
#define DNSLG_STDC_HEADERS 1
#define DNSLG_TIME_WITH_SYS_TIME 1
#define DNSLG_VERSION "2.6.5-11201"
#define DNSLG_restrict __restrict
#undef DNSLG_VERSION
// version 2.6.5.0-0
#define DNSLG_VERSION 0x020605000000LL// include/dnslg/dnslg-config-features.h

==> yadifa-2.6.7-1-x86_64.pkg.tar.zst: usr/include/dnslg/dnslg-config-features.h <==
#pragma once
#define DNSLG_DEFAULT_ASSUMED_CPU_COUNT 2
#define DNSLG_HAS_ACL_SUPPORT 1
#define DNSLG_HAS_BFD_DEBUG_SUPPORT 0
#define DNSLG_HAS_BUILD_TIMESTAMP 1
#define DNSLG_HAS_CC_ADDRESS_SANITIZER_CHECK 0
#define DNSLG_HAS_CC_ANSI 1
#define DNSLG_HAS_CC_ANSI_ALIAS 0
#define DNSLG_HAS_CC_CATCH_UNDEFINED_BEHAVIOR 0
#define DNSLG_HAS_CC_DWARF2 1
#define DNSLG_HAS_CC_DWARF3 1
#define DNSLG_HAS_CC_DWARF4 1
#define DNSLG_HAS_CC_EXCEPTIONS 1
#define DNSLG_HAS_CC_G 1
#define DNSLG_HAS_CC_G3 1
#define DNSLG_HAS_CC_M32 0
#define DNSLG_HAS_CC_M64 1
#define DNSLG_HAS_CC_MISSING_FIELD_INITIALIZERS 1
#define DNSLG_HAS_CC_NO_IDENT 1
#define DNSLG_HAS_CC_NO_OMIT_FRAME_POINTER 1
#define DNSLG_HAS_CC_NO_STRICT_ALIASING 1
#define DNSLG_HAS_CC_PEDANTIC 1
#define DNSLG_HAS_CC_RDYNAMIC 1
#define DNSLG_HAS_CC_SANITIZE_ADDRESS 1
#define DNSLG_HAS_CC_STACK_PROTECTOR 1
#define DNSLG_HAS_CC_STD_C11 1
#define DNSLG_HAS_CC_STD_C99 1
#define DNSLG_HAS_CC_STD_GNU11 1
#define DNSLG_HAS_CC_STD_GNU99 1
#define DNSLG_HAS_CC_TUNE_NATIVE 1
#define DNSLG_HAS_CC_WALL 1
#define DNSLG_HAS_CC_XC99 0
#define DNSLG_HAS_CLOSE_EX_REF 0
#define DNSLG_HAS_CPU_AMDINTEL 1
#define DNSLG_HAS_CTRL 1
#define DNSLG_HAS_DNSSEC_SUPPORT 1
#define DNSLG_HAS_DNSSEC_TOOLS 1
#define DNSLG_HAS_DYNUPDATE_SUPPORT 1
#define DNSLG_HAS_ECDSA_SUPPORT 1
#define DNSLG_HAS_EDDSA_SUPPORT 1
#define DNSLG_HAS_EVENT_DYNAMIC_MODULE 0
#define DNSLG_HAS_EVP_PKEY_NEW_RAW_PUBLIC_KEY 1
#define DNSLG_HAS_FULL_ASCII7 0
#define DNSLG_HAS_KEYGEN 0
#define DNSLG_HAS_LIBC_MALLOC_DEBUG_SUPPORT 0
#define DNSLG_HAS_LOCK_DEBUG_SUPPORT 0
#define DNSLG_HAS_LOGDIR 1
#define DNSLG_HAS_LOG_PID 1
#define DNSLG_HAS_LOG_THREAD_ID 0
#define DNSLG_HAS_LOG_THREAD_TAG 1
#define DNSLG_HAS_MALLOC_DEBUG_SUPPORT 0
#define DNSLG_HAS_MASTER_SUPPORT 1
#define DNSLG_HAS_MEMALIGN_ISSUES 0
#define DNSLG_HAS_MUTEX_DEBUG_SUPPORT 0
#define DNSLG_HAS_NON_AA_AXFR_SUPPORT 0
#define DNSLG_HAS_NSEC3_SUPPORT 1
#define DNSLG_HAS_NSEC_SUPPORT 1
#define DNSLG_HAS_NSID_SUPPORT 1
#define DNSLG_HAS_OPENSSL 1
#define DNSLG_HAS_PTHREAD_SETAFFINITY_NP 1
#define DNSLG_HAS_PTHREAD_SETNAME_NP 1
#define DNSLG_HAS_PTHREAD_SPINLOCK 1
#define DNSLG_HAS_RRL_SUPPORT 1
#define DNSLG_HAS_RRSIG_MANAGEMENT_SUPPORT 1
#define DNSLG_HAS_SETGROUPS 1
#define DNSLG_HAS_SOCKADDR_IN6_SIN6_LEN 0
#define DNSLG_HAS_SOCKADDR_IN_SIN_LEN 0
#define DNSLG_HAS_SOCKADDR_SA_LEN 0
#define DNSLG_HAS_SYNC_BUILTINS 1
#define DNSLG_HAS_SYSTEMD_RESOLVED_AVOIDANCE 1
#define DNSLG_HAS_TESTS 1
#define DNSLG_HAS_TOOLS 1
#define DNSLG_HAS_TRACK_ZONES_DEBUG_SUPPORT 0
#define DNSLG_HAS_TSIG_SUPPORT 1
#define DNSLG_HAS_WITH_LOGDIR "/var/log/yadifa" // /var/log/yadifa
#define DNSLG_HAS_YADIFA 1
#define DNSLG_HAS_ZALLOC_DEBUG_SUPPORT 0
#define DNSLG_HAS_ZALLOC_STATISTICS_SUPPORT 0
#define DNSLG_HAS_ZALLOC_SUPPORT 1
#define DNSLG_HAVE_ALARM 1
#define DNSLG_HAVE_ARPA_INET_H 1
#define DNSLG_HAVE_ASM_UNISTD_H 1
#define DNSLG_HAVE_ASSERT_H 1
#define DNSLG_HAVE_ATEXIT 1
#define DNSLG_HAVE_BFD_H 1
#define DNSLG_HAVE_BYTESWAP_H 1
#define DNSLG_HAVE_BZERO 1
#define DNSLG_HAVE_CHOWN 1
#define DNSLG_HAVE_CLOCK_GETTIME 1
#define DNSLG_HAVE_CPUID_H 1
#define DNSLG_HAVE_CTYPE_H 1
#define DNSLG_HAVE_DIRENT_H 1
#define DNSLG_HAVE_DLFCN_H 1
#define DNSLG_HAVE_DUP2 1
#define DNSLG_HAVE_ENDIAN_H 1
#define DNSLG_HAVE_ERRNO_H 1
#define DNSLG_HAVE_EXECINFO_H 1
#define DNSLG_HAVE_FCNTL_H 1
#define DNSLG_HAVE_FDATASYNC 1
#define DNSLG_HAVE_FORK 1
#define DNSLG_HAVE_FTRUNCATE 1
#define DNSLG_HAVE_GETCWD 1
#define DNSLG_HAVE_GETHOSTNAME 1
#define DNSLG_HAVE_GETOPT_H 1
#define DNSLG_HAVE_GETPAGESIZE 1
#define DNSLG_HAVE_GETTID 1
#define DNSLG_HAVE_GETTIMEOFDAY 1
#define DNSLG_HAVE_GRP_H 1
#define DNSLG_HAVE_INET_NTOA 1
#define DNSLG_HAVE_INT16_T 1
#define DNSLG_HAVE_INT32_T 1
#define DNSLG_HAVE_INT64_T 1
#define DNSLG_HAVE_INT8_T 1
#define DNSLG_HAVE_INTTYPES_H 1
#define DNSLG_HAVE_LIBC 1
#define DNSLG_HAVE_LIMITS_H 1
#define DNSLG_HAVE_LINUX_LIMITS_H 1
#define DNSLG_HAVE_LOCALTIME_R 1
#define DNSLG_HAVE_LONG_LONG 1
#define DNSLG_HAVE_MALLOC 1
#define DNSLG_HAVE_MALLOC_H 1
#define DNSLG_HAVE_MEMCHR 1
#define DNSLG_HAVE_MEMMOVE 1
#define DNSLG_HAVE_MEMSET 1
#define DNSLG_HAVE_MKDIR 1
#define DNSLG_HAVE_MKFIFO 1
#define DNSLG_HAVE_MMAP 1
#define DNSLG_HAVE_MUNMAP 1
#define DNSLG_HAVE_NETDB_H 1
#define DNSLG_HAVE_NETINET_IN_H 1
#define DNSLG_HAVE_NETINET_TCP_H 1
#define DNSLG_HAVE_NET_ETHERNET_H 1
#define DNSLG_HAVE_POLL_H 1
#define DNSLG_HAVE_PTHREAD_H 1
#define DNSLG_HAVE_PTRDIFF_T 1
#define DNSLG_HAVE_PWD_H 1
#define DNSLG_HAVE_REALLOC 1
#define DNSLG_HAVE_RECVMMSG 1
#define DNSLG_HAVE_SCHED_H 1
#define DNSLG_HAVE_SELECT 1
#define DNSLG_HAVE_SENDMMSG 1
#define DNSLG_HAVE_SIGNAL_H 1
#define DNSLG_HAVE_SOCKET 1
#define DNSLG_HAVE_STDARG_H 1
#define DNSLG_HAVE_STDATOMIC_H 1
#define DNSLG_HAVE_STDBOOL_H 1
#define DNSLG_HAVE_STDDEF_H 1
#define DNSLG_HAVE_STDINT_H 1
#define DNSLG_HAVE_STDIO_H 1
#define DNSLG_HAVE_STDLIB_H 1
#define DNSLG_HAVE_STDNORETURN_H 1
#define DNSLG_HAVE_STRCASECMP 1
#define DNSLG_HAVE_STRCHR 1
#define DNSLG_HAVE_STRDUP 1
#define DNSLG_HAVE_STRERROR 1
#define DNSLG_HAVE_STRINGS_H 1
#define DNSLG_HAVE_STRING_H 1
#define DNSLG_HAVE_STRNCASECMP 1
#define DNSLG_HAVE_STRRCHR 1
#define DNSLG_HAVE_STRTOL 1
#define DNSLG_HAVE_STRUCT_TM_TM_ZONE 1
#define DNSLG_HAVE_SYSLOG_H 1
#define DNSLG_HAVE_SYS_FILE_H 1
#define DNSLG_HAVE_SYS_IOCTL_H 1
#define DNSLG_HAVE_SYS_IPC_H 1
#define DNSLG_HAVE_SYS_MMAN_H 1
#define DNSLG_HAVE_SYS_MSG_H 1
#define DNSLG_HAVE_SYS_PARAM_H 1
#define DNSLG_HAVE_SYS_PRCTL_H 1
#define DNSLG_HAVE_SYS_RESOURCE_H 1
#define DNSLG_HAVE_SYS_SELECT_H 1
#define DNSLG_HAVE_SYS_SOCKET_H 1
#define DNSLG_HAVE_SYS_STAT_H 1
#define DNSLG_HAVE_SYS_TIME_H 1
#define DNSLG_HAVE_SYS_TYPES_H 1
#define DNSLG_HAVE_SYS_UN_H 1
#define DNSLG_HAVE_SYS_WAIT_H 1
#define DNSLG_HAVE_TIMEGM 1
#define DNSLG_HAVE_TIME_H 1
#define DNSLG_HAVE_TM_ZONE 1
#define DNSLG_HAVE_UCONTEXT_H 1
#define DNSLG_HAVE_UINT16_T 1
#define DNSLG_HAVE_UINT32_T 1
#define DNSLG_HAVE_UINT64_T 1
#define DNSLG_HAVE_UINT8_T 1
#define DNSLG_HAVE_UNISTD_H 1
#define DNSLG_HAVE_U_CHAR 1
#define DNSLG_HAVE_VFORK 1
#define DNSLG_HAVE_WORKING_FORK 1
#define DNSLG_HAVE_WORKING_VFORK 1
#define DNSLG_HAVE__BOOL 1
#define DNSLG_IS_BSD_FAMILY 0
#define DNSLG_IS_DARWIN_OS 0
#define DNSLG_IS_LINUX_FAMILY 1
#define DNSLG_IS_SOLARIS_FAMILY 0
#define DNSLG_LSTAT_FOLLOWS_SLASHED_SYMLINK 1
#define DNSLG_LT_OBJDIR ".libs/"
#define DNSLG_PACKAGE "yadifa"
#define DNSLG_PACKAGE_BUGREPORT "info@yadifa.eu"
#define DNSLG_PACKAGE_NAME "yadifa"
#define DNSLG_PACKAGE_STRING "yadifa 2.6.7-11259"
#define DNSLG_PACKAGE_TARNAME "yadifa"
#define DNSLG_PACKAGE_URL ""
#define DNSLG_PACKAGE_VERSION "2.6.7-11259"
#define DNSLG_SELECT_TYPE_ARG1 int
#define DNSLG_SELECT_TYPE_ARG234 (fd_set *)
#define DNSLG_SELECT_TYPE_ARG5 (struct timeval *)
#define DNSLG_STDC_HEADERS 1
#define DNSLG_VERSION "2.6.7-11259"
#define DNSLG_restrict __restrict__
#undef DNSLG_VERSION
// version 2.6.7.0-0
#define DNSLG_VERSION 0x020607000000LL// include/dnslg/dnslg-config-features.h
